%%
%% This is file `sr.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% fetchbibpes.dtx  (with options: `copyright,sr')
%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% fetchbibpes.sty package,                              %%
%% Copyright (C) 2016--2018                              %%
%%   dpstory@uakron.edu                                  %%
%%                                                       %%
%% This program can redistributed and/or modified under  %%
%% the terms of the LaTeX Project Public License         %%
%% Distributed from CTAN archives in directory           %%
%% macros/latex/base/lppl.txt; either version 1.2 of the %%
%% License, or (at your option) any later version.       %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newcommand{\sr}[2]{\def\@rgi{#1}\convBkN@mes{#2}%
  \ifx\@rgi\@empty\else\textit{#1}\ \fi
  \textbf{(\expandafter\pibibleverse\expandafter{\convdBkN@mes})}}%
\def\convBkN@mes#1{\let\convdBkN@mes\@empty
  \convBkN@mesi#1;;\@nil}
\def\convBkN@mesi#1 #2\@nil{%
  \def\fb@thisbook{#1}\fb@rmvspcsp{\fb@thisbook}%
  \fb@ifItsiiiLttrs#1\@nil
  \csname\fb@itsiii\endcsname
    \edef\fb@expand@add{\noexpand\g@addto@macro\noexpand
      \convdBkN@mes{\@nameuse{rev@\fb@thisbook}}}\else
    \edef\fb@expand@add{\noexpand\g@addto@macro\noexpand
          \convdBkN@mes{\fb@thisbook}}\fi
  \fb@expand@add
  \getp@ssage#2\@nil
}
\def\fb@ifItsiiiLttrs#1#2#3#4\@nil{\def\@rgiv{#4}\ifx\@rgiv\@empty
  \def\fb@itsiii{iftrue}\else\def\fb@itsiii{iffalse}\fi
}
\def\getp@ssage#1;#2;\@nil{\def\@rgii{#2}\fb@rmvspcsp{\@rgii}%
  \edef\fb@expand@add{\noexpand\g@addto@macro
        \noexpand\convdBkN@mes{ #1;}}%
  \fb@expand@add
  \edef\@rgii{\@rgii}\ifx\@rgii\@empty
    \def\fb@next{\fb@rmlstsemi}\else
    \def\fb@next{\expandafter\convBkN@mesi\@rgii;\@nil}\fi
  \fb@next
}
\def\fb@rmlstsemi{\expandafter\fb@rmlstsemii\convdBkN@mes\@nil}
\def\fb@rmlstsemii#1;\@nil{\def\convdBkN@mes{#1}}
\endinput
%%
%% End of file `sr.def'.
